@@ -35,7 +35,7 @@
 
 #include "config.h"
 
-static char rcsid[] not_used = {"$Id: WWWInt32.cc 19763 2008-10-28 19:55:14Z jimg $"};
+static char rcsid[] not_used = {"$Id: WWWInt32.cc 23485 2010-09-03 22:48:51Z jimg $"};
 
 #include <iostream>
 #include <string>
@@ -69,4 +69,16 @@ WWWInt32::print_val(ostream &strm, string, bool /*print_decl_p*/)
 {
     write_simple_variable(strm, this);
 }
+#if 0
+void
+WWWInt32::print_attributes(FILE *os)
+{
+    write_simple_var_attributes(os, this);
+}
 
+void
+WWWInt32::print_attributes(ostream &os, int rows, int cols)
+{
+    write_simple_var_attributes(os, rows, cols, this);
+}
+#endif
